@@ -4,11 +4,11 @@ import importlib
 
 from .shell import bot_runner
 
-entry_path = sys.argv[1]
+_, entry_path, *args = sys.argv
 
 entry_package_name, entry_name = entry_path.rsplit(".", 1)
 
 entry_package = importlib.import_module(entry_package_name)
 entry = getattr(entry_package, entry_name)
 
-asyncio.run(bot_runner(entry))
\ No newline at end of file
+asyncio.run(bot_runner(entry, *args))
\ No newline at end of file
